==> cdktf-cdktf-provider-null-0.1.118.tar.gz: package/lib/data-null-data-source.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataNullDataSourceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/null/d/data_source.html#has_computed_default DataNullDataSource#has_computed_default}.
     *
     * @stability stable
     */
    readonly hasComputedDefault?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/null/d/data_source.html#inputs DataNullDataSource#inputs}.
     *
     * @stability stable
     */
    readonly inputs?: {
        [key: string]: string;
    };
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/null/d/data_source.html null_data_source}.
 *
 * @stability stable
 */
export declare class DataNullDataSource extends cdktf.TerraformDataSource {
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/null/d/data_source.html null_data_source} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataNullDataSourceConfig);
    private _hasComputedDefault?;
    /**
     * @stability stable
     */
    get hasComputedDefault(): string;
    /**
     * @stability stable
     */
    set hasComputedDefault(value: string);
    /**
     * @stability stable
     */
    resetHasComputedDefault(): void;
    /**
     * @stability stable
     */
    get hasComputedDefaultInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _inputs?;
    /**
     * @stability stable
     */
    get inputs(): {
        [key: string]: string;
    };
    /**
     * @stability stable
     */
    set inputs(value: {
        [key: string]: string;
    });
    /**
     * @stability stable
     */
    resetInputs(): void;
    /**
     * @stability stable
     */
    get inputsInput(): {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    outputs(key: string): string;
    /**
     * @stability stable
     */
    get random(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}

==> cdktf-cdktf-provider-null-0.2.174.tar.gz: package/lib/data-null-data-source.d.ts <==
import { Construct } from 'constructs';
import * as cdktf from 'cdktf';
/**
 * @stability stable
 */
export interface DataNullDataSourceConfig extends cdktf.TerraformMetaArguments {
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/null/d/data_source.html#has_computed_default DataNullDataSource#has_computed_default}.
     *
     * @stability stable
     */
    readonly hasComputedDefault?: string;
    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/null/d/data_source.html#inputs DataNullDataSource#inputs}.
     *
     * @stability stable
     */
    readonly inputs?: {
        [key: string]: string;
    } | cdktf.IResolvable;
}
/**
 * Represents a {@link https://www.terraform.io/docs/providers/null/d/data_source.html null_data_source}.
 *
 * @stability stable
 */
export declare class DataNullDataSource extends cdktf.TerraformDataSource {
    /**
     * @stability stable
     */
    static readonly tfResourceType: string;
    /**
     * Create a new {@link https://www.terraform.io/docs/providers/null/d/data_source.html null_data_source} Data Source.
     *
     * @param scope The scope in which to define this construct.
     * @param id The scoped construct ID.
     * @stability stable
     */
    constructor(scope: Construct, id: string, config?: DataNullDataSourceConfig);
    private _hasComputedDefault?;
    /**
     * @stability stable
     */
    get hasComputedDefault(): string | undefined;
    /**
     * @stability stable
     */
    set hasComputedDefault(value: string | undefined);
    /**
     * @stability stable
     */
    resetHasComputedDefault(): void;
    /**
     * @stability stable
     */
    get hasComputedDefaultInput(): string | undefined;
    /**
     * @stability stable
     */
    get id(): string;
    private _inputs?;
    /**
     * @stability stable
     */
    get inputs(): {
        [key: string]: string;
    } | cdktf.IResolvable | undefined;
    /**
     * @stability stable
     */
    set inputs(value: {
        [key: string]: string;
    } | cdktf.IResolvable | undefined);
    /**
     * @stability stable
     */
    resetInputs(): void;
    /**
     * @stability stable
     */
    get inputsInput(): cdktf.IResolvable | {
        [key: string]: string;
    } | undefined;
    /**
     * @stability stable
     */
    outputs(key: string): string;
    /**
     * @stability stable
     */
    get random(): string;
    /**
     * @stability stable
     */
    protected synthesizeAttributes(): {
        [name: string]: any;
    };
}
